pub type AnimationContainer = AnimationContainer<Handle<UiNode>>;Expand description
UI-specific animation container.
Aliased Type
pub struct AnimationContainer { /* private fields */ }Trait Implementations
Sourceimpl AnimationContainerExt for AnimationContainer
impl AnimationContainerExt for AnimationContainer
Sourcefn update_animations(&mut self, ui: &mut UserInterface, dt: f32)
fn update_animations(&mut self, ui: &mut UserInterface, dt: f32)
Updates all animations in the container and applies their poses to respective nodes. This method is intended to
be used only by the internals of the engine!