Struct fyrox_ui::border::BorderBuilder
source · pub struct BorderBuilder {
pub widget_builder: WidgetBuilder,
pub stroke_thickness: Thickness,
}Expand description
Border builder.
Fields
widget_builder: WidgetBuilderWidget builder that will be used to build the base of the widget.
stroke_thickness: ThicknessStroke thickness for each side of the border. Default is 1px wide border for each side.
Implementations
sourceimpl BorderBuilder
impl BorderBuilder
sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates a new border builder with a widget builder specified.
sourcepub fn with_stroke_thickness(self, stroke_thickness: Thickness) -> Self
pub fn with_stroke_thickness(self, stroke_thickness: Thickness) -> Self
Sets the desired stroke thickness for each side of the border.
sourcepub fn build_border(self) -> Border
pub fn build_border(self) -> Border
Creates a Border widget, but does not add it to the user interface. Also see Self::build docs.