Module fyrox_ui::button

source ·
Defines a clickable widget with arbitrary content. See Button dos for more info and examples.

Structs

  • Defines a clickable widget with arbitrary content. The content could be any kind of widget, usually it is just a text or an image.
  • Button builder is used to create Button widget instances.

Enums

  • Possible button content. In general, button widget can contain any type of widget inside. This enum contains a special shortcuts for most commonly used cases - button with the default font, button with custom font, or button with any widget.
  • Messages that can be emitted by Button widget (or can be sent to the widget).