Enum fyrox_ui::button::ButtonMessage
source · pub enum ButtonMessage {
Click,
Content(ButtonContent),
}Expand description
Messages that can be emitted by Button widget (or can be sent to the widget).
Variants
Click
Emitted by the button widget when it was clicked by any mouse button. Click is a press with a following release
of a mouse button withing the button bounds. This message can be only emitted, not sent. See Button docs
for usage examples.
Content(ButtonContent)
A message, that can be used to set new content of the button. See ButtonContent for usage examples.
Implementations
sourceimpl ButtonMessage
impl ButtonMessage
sourcepub fn click(
destination: Handle<UiNode>,
direction: MessageDirection
) -> UiMessage
pub fn click( destination: Handle<UiNode>, direction: MessageDirection ) -> UiMessage
A shortcut method to create ButtonMessage::Click message.
sourcepub fn content(
destination: Handle<UiNode>,
direction: MessageDirection,
value: ButtonContent
) -> UiMessage
pub fn content( destination: Handle<UiNode>, direction: MessageDirection, value: ButtonContent ) -> UiMessage
A shortcut method to create ButtonMessage::Content message.