Struct fyrox_ui::button::ButtonBuilder
source · pub struct ButtonBuilder { /* private fields */ }Expand description
Button builder is used to create Button widget instances.
Implementations
sourceimpl ButtonBuilder
impl ButtonBuilder
sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates a new button builder with a widget builder instance.
sourcepub fn with_text(self, text: &str) -> Self
pub fn with_text(self, text: &str) -> Self
Sets the content of the button to be ButtonContent::Text (text with the default font).
sourcepub fn with_text_and_font(self, text: &str, font: SharedFont) -> Self
pub fn with_text_and_font(self, text: &str, font: SharedFont) -> Self
Sets the content of the button to be ButtonContent::Text (text with a custom font).
sourcepub fn with_content(self, node: Handle<UiNode>) -> Self
pub fn with_content(self, node: Handle<UiNode>) -> Self
Sets the content of the button to be ButtonContent::Node (arbitrary widget handle).
sourcepub fn with_back(self, decorator: Handle<UiNode>) -> Self
pub fn with_back(self, decorator: Handle<UiNode>) -> Self
Specifies the widget that will be used as a content holder of the button. By default it is an
instance of crate::decorator::Decorator widget. Usually, this widget should respond to mouse
events to highlight button state (hovered, pressed, etc.)
sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
Finishes button build and adds to the user interface and returns its handle.