Struct fyrox_ui::check_box::CheckBoxBuilder
source · pub struct CheckBoxBuilder { /* private fields */ }Expand description
Check box builder creates CheckBox instances and adds them to the user interface.
Implementations
sourceimpl CheckBoxBuilder
impl CheckBoxBuilder
sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates new check box builder instance.
sourcepub fn with_check_mark(self, check_mark: Handle<UiNode>) -> Self
pub fn with_check_mark(self, check_mark: Handle<UiNode>) -> Self
Sets the desired check mark when the state is Some(true).
sourcepub fn with_uncheck_mark(self, uncheck_mark: Handle<UiNode>) -> Self
pub fn with_uncheck_mark(self, uncheck_mark: Handle<UiNode>) -> Self
Sets the desired check mark when the state is Some(false).
sourcepub fn with_undefined_mark(self, undefined_mark: Handle<UiNode>) -> Self
pub fn with_undefined_mark(self, undefined_mark: Handle<UiNode>) -> Self
Sets the desired check mark when the state is None.
sourcepub fn with_content(self, content: Handle<UiNode>) -> Self
pub fn with_content(self, content: Handle<UiNode>) -> Self
Sets the new content of the check box.
sourcepub fn with_background(self, background: Handle<UiNode>) -> Self
pub fn with_background(self, background: Handle<UiNode>) -> Self
Sets the desired background widget that will be used a container for check box contents. By default, it is a simple border.
sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
Finishes check box building and adds it to the user interface.