pub struct DrawingContext {
pub render_data: RenderData,
pub transform_stack: TransformStack,
pub style: StyleResource,
pub elapsed_time: f32,
/* private fields */
}Fields
render_data: RenderDatatransform_stack: TransformStackstyle: StyleResourceelapsed_time: f32Amount of time (in seconds) that passed from the creation of the engine. Keep in mind that this value is not guaranteed to match real time. A user can change delta time with which the engine “ticks” and this delta time affects elapsed time.
Implementations
Sourceimpl DrawingContext
impl DrawingContext
pub fn new(style: StyleResource) -> DrawingContext
pub fn clear(&mut self)
pub fn copy_render_data_and_clear(&mut self, dest: &mut RenderData)
pub fn append(&mut self, render_data: &RenderData)
pub fn get_vertices(&self) -> &[Vertex]
pub fn get_triangles(&self) -> &[TriangleDefinition]
pub fn get_commands(&self) -> &Vec<Command>
pub fn push_opacity(&mut self, opacity: f32)
pub fn pop_opacity(&mut self)
pub fn triangle_points( &self, triangle: &TriangleDefinition, ) -> Option<(&Vertex, &Vertex, &Vertex)>
pub fn is_command_contains_point( &self, command: &Command, pos: Vector2<f32>, ) -> bool
pub fn commit( &mut self, clip_bounds: Rect<f32>, brush: Brush, texture: CommandTexture, material: &MaterialResource, clipping_geometry: Option<ClippingGeometry>, )
pub fn draw_text( &mut self, clip_bounds: Rect<f32>, position: Vector2<f32>, material: &MaterialResource, formatted_text: &FormattedText, )