pub struct DropdownListBuilder { /* private fields */ }Expand description
Dropdown list builder allows to create DropdownList widgets and add them a user interface.
Implementations
Sourceimpl DropdownListBuilder
impl DropdownListBuilder
Sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates new dropdown list builder.
Sourcepub fn with_items(self, items: Vec<Handle<UiNode>>) -> Self
pub fn with_items(self, items: Vec<Handle<UiNode>>) -> Self
Sets the desired items of the dropdown list.
Sourcepub fn with_selected(self, index: usize) -> Self
pub fn with_selected(self, index: usize) -> Self
Sets the selected item of the dropdown list.
Sourcepub fn with_opt_selected(self, index: Option<usize>) -> Self
pub fn with_opt_selected(self, index: Option<usize>) -> Self
Sets the desired items of the dropdown list.
Sourcepub fn with_close_on_selection(self, value: bool) -> Self
pub fn with_close_on_selection(self, value: bool) -> Self
Sets a flag, that defines whether the dropdown list should close on selection or not.
Sourcepub fn with_items_constraint(self, constraint: Vector2<f32>) -> Self
pub fn with_items_constraint(self, constraint: Vector2<f32>) -> Self
Sets the desired constraint for the inner items. By default, it is unconstrained (+infinity).
Sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<DropdownList>where
Self: Sized,
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<DropdownList>where
Self: Sized,
Finishes list building and adds it to the given user interface.