Enum fyrox_ui::VerticalAlignment
source · pub enum VerticalAlignment {
Stretch,
Top,
Center,
Bottom,
}Expand description
Horizontal alignment defines relative location and size of the widget to its parent widget along vertical (Y) axis.
Variants
Stretch
Tells the widget to take all available space along vertical axis and stay at top side of the parent widget. This is default vertical alignment for all widgets.
Top
Tells the widget to stay at the top side of the parent widget and take as less space as possible (shrink-to-fit).
Center
Tells the widget to stay at the center of the parent widget and take as less space as possible (shrink-to-fit).
Bottom
Tells the widget to stay at the bottom side of the parent widget and take as less space as possible (shrink-to-fit).