Enum fyrox_ui::expander::ExpanderMessage
source · pub enum ExpanderMessage {
Expand(bool),
}Expand description
A set messages that can be used to either alternate the state of an Expander widget, or to listen for
state changes.
Variants
Expand(bool)
A message, that could be used to either switch expander state (with MessageDirection::ToWidget) or
to get its new state MessageDirection::FromWidget.
Implementations
sourceimpl ExpanderMessage
impl ExpanderMessage
sourcepub fn expand(
destination: Handle<UiNode>,
direction: MessageDirection,
value: bool
) -> UiMessage
pub fn expand( destination: Handle<UiNode>, direction: MessageDirection, value: bool ) -> UiMessage
Creates ExpanderMessage::Expand message.