pub struct FileBrowserBuilder { /* private fields */ }

Implementations

source

impl FileBrowserBuilder

source

pub fn new(widget_builder: WidgetBuilder) -> Self

source

pub fn with_filter(self, filter: Filter) -> Self

source

pub fn with_opt_filter(self, filter: Option<Filter>) -> Self

source

pub fn with_mode(self, mode: FileBrowserMode) -> Self

source

pub fn with_show_path(self, show_path: bool) -> Self

source

pub fn with_path<P: AsRef<Path>>(self, path: P) -> Self

Sets desired path which will be used to build file system tree.

Notes

It does not bring tree item with given path into view because it is impossible during construction stage - there is not enough layout information to do so. You can send FileBrowserMessage::Path right after creation and it will bring tree item into view without any problems. It is possible because all widgets were created at that moment and layout system can give correct offsets to bring item into view.

source

pub fn with_root(self, root: PathBuf) -> Self

source

pub fn with_opt_root(self, root: Option<PathBuf>) -> Self

source

pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>