pub enum SizeMode {
Strict,
Auto,
Stretch,
}Expand description
Size mode defines how grid’s dimension (see GridDimension) will behave on layout step.
Variants
Strict
Strict size of the dimension.
Auto
Size of the dimension will match the size of the inner content.
Stretch
Size of the dimension will stretch to fit available bounds.