pub struct Cell {
pub nodes: Vec<Handle<UiNode>>,
pub width_constraint: Option<f32>,
pub height_constraint: Option<f32>,
pub row_index: usize,
pub column_index: usize,
}Expand description
Cell of the grid, that contains additional information for layout purposes. It does not have any particular use outside of grid’s internals.
Fields
nodes: Vec<Handle<UiNode>>A set of nodes of the cell.
width_constraint: Option<f32>Current width constraint of the cell.
height_constraint: Option<f32>Current height constraint of the cell.
row_index: usizeVertical location of the cell (row number).
column_index: usizeHorizontal location of the cell (column number).