Struct fyrox_ui::grid::GridBuilder
source · pub struct GridBuilder { /* private fields */ }Expand description
Grid builder creates Grid instances and adds it to the user interface.
Implementations
sourceimpl GridBuilder
impl GridBuilder
sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates new grid builder with the base widget builder.
sourcepub fn add_row(self, row: Row) -> Self
pub fn add_row(self, row: Row) -> Self
Adds a new row to the grid builder. Number of rows is unlimited.
sourcepub fn add_column(self, column: Column) -> Self
pub fn add_column(self, column: Column) -> Self
Adds a new column to the grid builder. Number of columns is unlimited.
sourcepub fn add_rows(self, rows: Vec<Row>) -> Self
pub fn add_rows(self, rows: Vec<Row>) -> Self
Adds a set of rows to the grid builder. Number of rows is unlimited.
sourcepub fn add_columns(self, columns: Vec<Column>) -> Self
pub fn add_columns(self, columns: Vec<Column>) -> Self
Adds a set of columnds to the grid builder. Number of columnds is unlimited.
sourcepub fn draw_border(self, value: bool) -> Self
pub fn draw_border(self, value: bool) -> Self
Specifies whether the grid should draw its border or not.
sourcepub fn with_border_thickness(self, value: f32) -> Self
pub fn with_border_thickness(self, value: f32) -> Self
Specifies grid’s border thickness.