Type Alias fyrox_ui::grid::Column

source ·
pub type Column = GridDimension;
Type alias for grid columns.

Aliased Type

struct Column {
    pub size_mode: SizeMode,
    pub desired_size: f32,
    pub actual_size: f32,
    pub location: f32,
}

Fields

size_mode: SizeMode

Current size mode of the dimension.

desired_size: f32

Desired size of the dimension. Makes sense only if size mode is SizeMode::Strict.

actual_size: f32

Measured size of the dimension. It could be considered as “output” parameter of the dimension that will be filled after measurement layout step.

location: f32

Local position along the axis of the dimension after arrangement step.