Enum fyrox_ui::image::ImageMessage
source · pub enum ImageMessage {
Texture(Option<SharedTexture>),
Flip(bool),
UvRect(Rect<f32>),
CheckerboardBackground(bool),
}Expand description
A set of messages that could be used to alter Image widget state at runtime.
Variants
Texture(Option<SharedTexture>)
Used to set new texture of the Image widget.
Flip(bool)
Used to enable or disable texture flip of the Image widget. See respective section
of the docs for more info.
UvRect(Rect<f32>)
Used to set specific portion of the texture. See respective section of the docs for more info.
CheckerboardBackground(bool)
Used to enable or disable checkerboard background. See respective section of the docs for more info.
Implementations
sourceimpl ImageMessage
impl ImageMessage
sourcepub fn texture(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Option<SharedTexture>
) -> UiMessage
pub fn texture( destination: Handle<UiNode>, direction: MessageDirection, value: Option<SharedTexture> ) -> UiMessage
Creates ImageMessage::Texture message.
sourcepub fn flip(
destination: Handle<UiNode>,
direction: MessageDirection,
value: bool
) -> UiMessage
pub fn flip( destination: Handle<UiNode>, direction: MessageDirection, value: bool ) -> UiMessage
Creates ImageMessage::Flip message.
sourcepub fn uv_rect(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Rect<f32>
) -> UiMessage
pub fn uv_rect( destination: Handle<UiNode>, direction: MessageDirection, value: Rect<f32> ) -> UiMessage
Creates ImageMessage::UvRect message.
sourcepub fn checkerboard_background(
destination: Handle<UiNode>,
direction: MessageDirection,
value: bool
) -> UiMessage
pub fn checkerboard_background( destination: Handle<UiNode>, direction: MessageDirection, value: bool ) -> UiMessage
Creates ImageMessage::CheckerboardBackground message.