Struct fyrox_ui::image::ImageBuilder
source · pub struct ImageBuilder { /* private fields */ }Expand description
Image builder is used to create Image widget instances and register them in the user interface.
Implementations
sourceimpl ImageBuilder
impl ImageBuilder
sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates new image builder with the base widget builder specified.
sourcepub fn with_flip(self, flip: bool) -> Self
pub fn with_flip(self, flip: bool) -> Self
Sets whether the image should be flipped vertically or not. See respective section of the docs for more info.
sourcepub fn with_texture(self, texture: SharedTexture) -> Self
pub fn with_texture(self, texture: SharedTexture) -> Self
Sets the texture that will be used for drawing.
sourcepub fn with_opt_texture(self, texture: Option<SharedTexture>) -> Self
pub fn with_opt_texture(self, texture: Option<SharedTexture>) -> Self
Specifies the texture that will be used for drawing.
sourcepub fn with_uv_rect(self, uv_rect: Rect<f32>) -> Self
pub fn with_uv_rect(self, uv_rect: Rect<f32>) -> Self
Specifies a portion of the texture in normalized coordinates. See respective section of the docs for more info.
sourcepub fn with_checkerboard_background(self, checkerboard_background: bool) -> Self
pub fn with_checkerboard_background(self, checkerboard_background: bool) -> Self
Sets whether the image should use checkerboard background or not. See respective section of the docs for more info.
sourcepub fn build_node(self) -> UiNode
pub fn build_node(self) -> UiNode
Builds the Image widget, but does not add it to the UI.