pub enum HotKey {
NotSet,
Some {
code: KeyCode,
modifiers: KeyboardModifiers,
},
}Expand description
Hot key is a combination of a key code with an arbitrary set of keyboard modifiers (such as Ctrl, Shift, Alt keys).
Variants
Implementations
sourceimpl HotKey
impl HotKey
sourcepub fn from_key_code(key: KeyCode) -> Self
pub fn from_key_code(key: KeyCode) -> Self
Creates a new hot key that consists of a single key, without any modifiers.
sourcepub fn ctrl_key(key: KeyCode) -> Self
pub fn ctrl_key(key: KeyCode) -> Self
Creates a new hot key, that consists of combination Ctrl + Key.