Enum fyrox_ui::key::HotKeyEditorMessage
source · pub enum HotKeyEditorMessage {
Value(HotKey),
}Expand description
A set of messages, that is used to alternate the state of HotKeyEditor widget or to listen to its changes.
Variants
Value(HotKey)
A message, that is either used to modify current value of a HotKey widget instance (with MessageDirection::ToWidget)
or to listen to its changes (with MessageDirection::FromWidget).
Implementations
sourceimpl HotKeyEditorMessage
impl HotKeyEditorMessage
sourcepub fn value(
destination: Handle<UiNode>,
direction: MessageDirection,
value: HotKey
) -> UiMessage
pub fn value( destination: Handle<UiNode>, direction: MessageDirection, value: HotKey ) -> UiMessage
Creates HotKeyEditorMessage::Value message.