pub enum ListViewMessage {
    SelectionChanged(Option<usize>),
    Items(Vec<Handle<UiNode>>),
    AddItem(Handle<UiNode>),
    RemoveItem(Handle<UiNode>),
    BringItemIntoView(Handle<UiNode>),
}
A set of messages that can be used to modify/fetch the state of a ListView widget at runtime.

Variants



SelectionChanged(Option<usize>)

A message, that is used to either fetch or modify current selection of a ListView widget. See ff



Items(Vec<Handle<UiNode>>)

A message, that is used to set new items of a list view.



AddItem(Handle<UiNode>)

A message, that is used to add an item to a list view.



RemoveItem(Handle<UiNode>)

A message, that is used to remove an item from a list view.



BringItemIntoView(Handle<UiNode>)

A message, that is used to bring an item into view.

Implementations

source

impl ListViewMessage

source

pub fn selection( destination: Handle<UiNode>, direction: MessageDirection, value: Option<usize> ) -> UiMessage

source

pub fn items( destination: Handle<UiNode>, direction: MessageDirection, value: Vec<Handle<UiNode>> ) -> UiMessage

Creates ListViewMessage::Items message.

source

pub fn add_item( destination: Handle<UiNode>, direction: MessageDirection, value: Handle<UiNode> ) -> UiMessage

Creates ListViewMessage::AddItem message.

source

pub fn remove_item( destination: Handle<UiNode>, direction: MessageDirection, value: Handle<UiNode> ) -> UiMessage

Creates ListViewMessage::RemoveItem message.

source

pub fn bring_item_into_view( destination: Handle<UiNode>, direction: MessageDirection, value: Handle<UiNode> ) -> UiMessage