Struct fyrox_ui::list_view::ListViewBuilder
source · pub struct ListViewBuilder { /* private fields */ }Expand description
List view builder is used to create ListView widget instances and add them to a user interface.
Implementations
sourceimpl ListViewBuilder
impl ListViewBuilder
sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates new list view builder.
sourcepub fn with_items(self, items: Vec<Handle<UiNode>>) -> Self
pub fn with_items(self, items: Vec<Handle<UiNode>>) -> Self
Sets an array of handle of desired items for the list view.
sourcepub fn with_items_panel(self, panel: Handle<UiNode>) -> Self
pub fn with_items_panel(self, panel: Handle<UiNode>) -> Self
Sets the desired item panel that will be used to arrange the items.
sourcepub fn with_scroll_viewer(self, sv: Handle<UiNode>) -> Self
pub fn with_scroll_viewer(self, sv: Handle<UiNode>) -> Self
Sets the desired scroll viewer.
sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
Finishes list view building and adds it to the user interface.