pub struct MenuItemBuilder { /* private fields */ }Expand description
Menu builder creates MenuItem widgets and adds them to the user interface.
Implementations
Sourceimpl MenuItemBuilder
impl MenuItemBuilder
Sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates new menu item builder instance.
Sourcepub fn with_content(self, content: MenuItemContent) -> Self
pub fn with_content(self, content: MenuItemContent) -> Self
Sets the desired content of the menu item. In most cases MenuItemContent::text_no_arrow is enough here.
Sourcepub fn with_items(self, items: Vec<Handle<MenuItem>>) -> Self
pub fn with_items(self, items: Vec<Handle<MenuItem>>) -> Self
Sets the desired items of the menu.
Sourcepub fn with_back(self, handle: Handle<UiNode>) -> Self
pub fn with_back(self, handle: Handle<UiNode>) -> Self
Allows you to specify the background content. Background node is only for decoration purpose, it can be any kind of node, by default it is a Decorator.
Sourcepub fn with_clickable_when_not_empty(self, value: bool) -> Self
pub fn with_clickable_when_not_empty(self, value: bool) -> Self
Sets whether the menu item is clickable when it has sub-items or not.
Sourcepub fn with_restrict_picking(self, restrict_picking: bool) -> Self
pub fn with_restrict_picking(self, restrict_picking: bool) -> Self
Sets a flag, that defines whether the popup should restrict all the mouse input or not.
Sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<MenuItem>
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<MenuItem>
Finishes menu item building and adds it to the user interface.