pub trait MessageData: BaseMessageData {
// Provided method
fn need_perform_layout(&self) -> bool { ... }
}Expand description
A trait for any message that can be put to the UI message queue.
Provided Methods
Sourcefn need_perform_layout(&self) -> bool
fn need_perform_layout(&self) -> bool
Returns true when the message starts a new layout pass before being passed to its
destination.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".