Enum fyrox_ui::messagebox::MessageBoxMessage
source · pub enum MessageBoxMessage {
Open {
title: Option<String>,
text: Option<String>,
},
Close(MessageBoxResult),
}Expand description
A set of messages that can be used to communicate with message boxes.
Variants
Open
Fields
A message that can be used to open message box, and optionally change its title and/or text.
Close(MessageBoxResult)
A message that can be used to close a message box with some result. It can also be read to get the changes
from the UI. See MessageBox docs for examples.
Implementations
sourceimpl MessageBoxMessage
impl MessageBoxMessage
sourcepub fn open(
destination: Handle<UiNode>,
direction: MessageDirection,
title: Option<String>,
text: Option<String>
) -> UiMessage
pub fn open( destination: Handle<UiNode>, direction: MessageDirection, title: Option<String>, text: Option<String> ) -> UiMessage
Creates MessageBoxMessage::Open message.
sourcepub fn close(
destination: Handle<UiNode>,
direction: MessageDirection,
value: MessageBoxResult
) -> UiMessage
pub fn close( destination: Handle<UiNode>, direction: MessageDirection, value: MessageBoxResult ) -> UiMessage
Creates MessageBoxMessage::Close message.