Enum fyrox_ui::messagebox::MessageBoxResult
source · pub enum MessageBoxResult {
Ok,
No,
Yes,
Cancel,
}Expand description
A set of possible reasons why a message box was closed.
Variants
Ok
Ok button was pressed. It can be emitted only if your message box was created with MessageBoxButtons::Ok.
No
No button was pressed. It can be emitted only if your message box was created with MessageBoxButtons::YesNo or
MessageBoxButtons::YesNoCancel.
Yes
Yes button was pressed. It can be emitted only if your message box was created with MessageBoxButtons::YesNo or
MessageBoxButtons::YesNoCancel.
Cancel
Cancel button was pressed. It can be emitted only if your message box was created with MessageBoxButtons::YesNoCancel.