Struct fyrox_ui::messagebox::MessageBoxBuilder
source · pub struct MessageBoxBuilder<'b> { /* private fields */ }Expand description
Creates MessageBox widgets and adds them to user interface.
Implementations
sourceimpl<'b> MessageBoxBuilder<'b>
impl<'b> MessageBoxBuilder<'b>
sourcepub fn new(window_builder: WindowBuilder) -> Self
pub fn new(window_builder: WindowBuilder) -> Self
Creates new builder instace. window_builder could be used to customize the look of you message box.
Sets a desired set of buttons of the message box.
sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
Finished message box building and adds it to the user interface.