Module fyrox_ui::numeric

source ·
A widget that handles numbers of any machine type. See NumericUpDown docs for more info and usage examples.

Structs

  • A widget that handles numbers of any machine type. Use this widget if you need to provide input field for a numeric type.
  • This builder creates new instances of NumericUpDown widget and adds them to the user interface.

Enums

Traits

  • Numeric type is a trait, that has all required traits of a number type. It is used as a useful abstraction over all machine numeric types.