Struct fyrox_ui::numeric::NumericUpDownBuilder
source · pub struct NumericUpDownBuilder<T: NumericType> { /* private fields */ }Expand description
This builder creates new instances of NumericUpDown widget and adds them to the user interface.
Implementations
sourceimpl<T: NumericType> NumericUpDownBuilder<T>
impl<T: NumericType> NumericUpDownBuilder<T>
sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates new builder instance with the base widget builder specified.
sourcepub fn with_min_value(self, value: T) -> Self
pub fn with_min_value(self, value: T) -> Self
Sets the desired min value.
sourcepub fn with_max_value(self, value: T) -> Self
pub fn with_max_value(self, value: T) -> Self
Sets the desired max value.
sourcepub fn with_value(self, value: T) -> Self
pub fn with_value(self, value: T) -> Self
Sets the desired value.
sourcepub fn with_precision(self, precision: usize) -> Self
pub fn with_precision(self, precision: usize) -> Self
Sets the desired precision.
sourcepub fn with_editable(self, editable: bool) -> Self
pub fn with_editable(self, editable: bool) -> Self
Enables or disables editing of the widget.
sourcepub fn with_drag_value_scaling(self, drag_value_scaling: f32) -> Self
pub fn with_drag_value_scaling(self, drag_value_scaling: f32) -> Self
Sets the desired value scaling when dragging. It scales cursor movement value (along Y axis) and multiplies it to get the new value.
sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
Finishes NumericUpDown widget creation and adds the new instance to the user interface and returns a handle to it.