NumericType

Trait NumericType 

pub trait NumericType:
    NumAssign
    + FromStr
    + Clone
    + Copy
    + NumOps
    + PartialOrd
    + Display
    + Bounded
    + Debug
    + Send
    + Sync
    + NumCast
    + Default
    + Reflect
    + Visit
    + TypeUuidProvider
    + 'static { }
Numeric type is a trait, that has all required traits of a number type. It is used as a useful abstraction over all machine numeric types.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors