pub struct PathEditorBuilder { /* private fields */ }Expand description
Path editor builder creates PathEditor instances and adds them to the user interface.
Implementations
Sourceimpl PathEditorBuilder
impl PathEditorBuilder
Sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates new builder instance.
Sourcepub fn with_file_types(self, filter: PathFilter) -> Self
pub fn with_file_types(self, filter: PathFilter) -> Self
Sets a filter that will be used in the file browser created by clicking on ... button.
Sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<PathEditor>
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<PathEditor>
Finishes widget building and adds it to the user interface returning a handle to the instance.