Enum fyrox_ui::popup::PopupMessage
source · pub enum PopupMessage {
Open,
Close,
Content(Handle<UiNode>),
Placement(Placement),
AdjustPosition,
}Expand description
A set of messages for Popup widget.
Variants
Open
Used to open a Popup widgets. Use PopupMessage::open to create the message.
Close
Used to close a Popup widgets. Use PopupMessage::close to create the message.
Content(Handle<UiNode>)
Used to change the content of a Popup widgets. Use PopupMessage::content to create the message.
Placement(Placement)
Used to change popup’s placement. Use PopupMessage::placement to create the message.
AdjustPosition
Used to adjust position of a popup widget, so it will be on screen. Use PopupMessage::adjust_position to create
the message.
Implementations
sourceimpl PopupMessage
impl PopupMessage
sourcepub fn open(
destination: Handle<UiNode>,
direction: MessageDirection
) -> UiMessage
pub fn open( destination: Handle<UiNode>, direction: MessageDirection ) -> UiMessage
Creates PopupMessage::Open message.
sourcepub fn close(
destination: Handle<UiNode>,
direction: MessageDirection
) -> UiMessage
pub fn close( destination: Handle<UiNode>, direction: MessageDirection ) -> UiMessage
Creates PopupMessage::Close message.
sourcepub fn content(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Handle<UiNode>
) -> UiMessage
pub fn content( destination: Handle<UiNode>, direction: MessageDirection, value: Handle<UiNode> ) -> UiMessage
Creates PopupMessage::Content message.
sourcepub fn placement(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Placement
) -> UiMessage
pub fn placement( destination: Handle<UiNode>, direction: MessageDirection, value: Placement ) -> UiMessage
Creates PopupMessage::Placement message.
sourcepub fn adjust_position(
destination: Handle<UiNode>,
direction: MessageDirection
) -> UiMessage
pub fn adjust_position( destination: Handle<UiNode>, direction: MessageDirection ) -> UiMessage
Creates PopupMessage::AdjustPosition message.