Enum fyrox_ui::range::RangeEditorMessage
source · pub enum RangeEditorMessage<T>where
T: NumericType,{
Value(Range<T>),
}Expand description
A set of messages, that can be used to modify/fetch the state of a RangeEditor widget instance.
Variants
Value(Range<T>)
A message, that is used to either modifying or fetching the value of a RangeEditor widget instance.
Implementations
sourceimpl<T: NumericType> RangeEditorMessage<T>
impl<T: NumericType> RangeEditorMessage<T>
sourcepub fn value(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Range<T>
) -> UiMessage
pub fn value( destination: Handle<UiNode>, direction: MessageDirection, value: Range<T> ) -> UiMessage
Creates RangeEditorMessage::Value message.