Enum fyrox_ui::scroll_bar::ScrollBarMessage
source · pub enum ScrollBarMessage {
Value(f32),
MinValue(f32),
MaxValue(f32),
}Expand description
A set of messages that can be accepted by ScrollBar widget.
Variants
Value(f32)
Used to indicate that the value of the scroll bar has changed (MessageDirection::FromWidget) or to set a
new value (with MessageDirection::ToWidget.
MinValue(f32)
Used to indicate that the min value of the scroll bar has changed (MessageDirection::FromWidget) or to set a
new min value (with MessageDirection::ToWidget.
MaxValue(f32)
Used to indicate that the max value of the scroll bar has changed (MessageDirection::FromWidget) or to set a
new max value (with MessageDirection::ToWidget.
Implementations
sourceimpl ScrollBarMessage
impl ScrollBarMessage
sourcepub fn value(
destination: Handle<UiNode>,
direction: MessageDirection,
value: f32
) -> UiMessage
pub fn value( destination: Handle<UiNode>, direction: MessageDirection, value: f32 ) -> UiMessage
Creates ScrollBarMessage::Value message.
sourcepub fn max_value(
destination: Handle<UiNode>,
direction: MessageDirection,
value: f32
) -> UiMessage
pub fn max_value( destination: Handle<UiNode>, direction: MessageDirection, value: f32 ) -> UiMessage
Creates ScrollBarMessage::MaxValue message.
sourcepub fn min_value(
destination: Handle<UiNode>,
direction: MessageDirection,
value: f32
) -> UiMessage
pub fn min_value( destination: Handle<UiNode>, direction: MessageDirection, value: f32 ) -> UiMessage
Creates ScrollBarMessage::MinValue message.