Struct fyrox_ui::scroll_bar::ScrollBar
source · pub struct ScrollBar {Show 14 fields
pub widget: Widget,
pub min: f32,
pub max: f32,
pub value: f32,
pub step: f32,
pub orientation: Orientation,
pub is_dragging: bool,
pub offset: Vector2<f32>,
pub increase: Handle<UiNode>,
pub decrease: Handle<UiNode>,
pub indicator: Handle<UiNode>,
pub indicator_canvas: Handle<UiNode>,
pub value_text: Handle<UiNode>,
pub value_precision: usize,
}Expand description
Scroll bar is used to represent a value on a finite range. It has a thumb that shows the current value on
on the bar. Usually it is used in pair with crate::scroll_panel::ScrollPanel to create something like
crate::scroll_viewer::ScrollViewer widget. However, it could also be used to create sliders to show some
value that lies within some range.
Example
A simple example of how to create a new ScrollBar could be something like this:
fn create_scroll_bar(ctx: &mut BuildContext) -> Handle<UiNode> {
ScrollBarBuilder::new(WidgetBuilder::new())
.with_min(0.0)
.with_max(200.0)
.with_value(123.0)
.build(ctx)
}It creates a horizontal scroll bar with 123.0 value and a range of [0.0..200.0]. To fetch the new value
of the scroll bar, use ScrollBarMessage::Value message:
if message.destination() == scroll_bar
&& message.direction() == MessageDirection::FromWidget
{
if let Some(ScrollBarMessage::Value(value)) = message.data() {
println!("{}", value);
}
}Please note, that you need to explicitly filter messages by MessageDirection::FromWidget, because it’s the only
direction that is used as an “indicator” that the value was accepted by the scroll bar.
Orientation
Scroll bar could be either horizontal (default) or vertical. You can select the orientation when building
a scroll bar using ScrollBarBuilder::with_orientation method and provide a desired value from Orientation
enum there.
Show values
By default, scroll bar does not show its actual value, you can turn it on using ScrollBarBuilder::show_value
method with true as the first argument. To change rounding of the value, use ScrollBarBuilder::with_value_precision
and provide the desired amount of decimal places there.
Step
Scroll bar provides arrows to change the current value using a fixed step value. You can change it using
ScrollBarBuilder::with_step method.
Fields
widget: WidgetBase widget of the scroll bar.
min: f32Min value of the scroll bar.
max: f32Max value of the scroll bar.
value: f32Current value of the scroll bar.
step: f32Step of the scroll bar.
orientation: OrientationCurrent orientation of the scroll bar.
is_dragging: boolInternal flag, that could be used to check whether the scroll bar’s thumb is being dragged or not.
offset: Vector2<f32>Internal mouse offset that is used for dragging purposes.
increase: Handle<UiNode>A handle of the increase button.
decrease: Handle<UiNode>A handle of the decrease button.
indicator: Handle<UiNode>A handle of the indicator (thumb).
indicator_canvas: Handle<UiNode>A handle of the canvas that is used for the thumb.
value_text: Handle<UiNode>A handle of the crate::text::Text widget that is used to show the current value of the scroll bar.
value_precision: usizeCurrent value precison in decimal places.
Methods from Deref<Target = Widget>
sourcepub fn set_name<P: AsRef<str>>(&mut self, name: P) -> &mut Self
pub fn set_name<P: AsRef<str>>(&mut self, name: P) -> &mut Self
Sets the new name of the widget.
sourcepub fn actual_local_size(&self) -> Vector2<f32>
pub fn actual_local_size(&self) -> Vector2<f32>
Returns the actual size of the widget after the full layout cycle.
sourcepub fn actual_initial_size(&self) -> Vector2<f32>
pub fn actual_initial_size(&self) -> Vector2<f32>
Returns size of the widget without any layout or rendering transform applied.
sourcepub fn actual_global_size(&self) -> Vector2<f32>
pub fn actual_global_size(&self) -> Vector2<f32>
Returns the actual global size of the widget after the full layout cycle.
sourcepub fn set_min_size(&mut self, value: Vector2<f32>) -> &mut Self
pub fn set_min_size(&mut self, value: Vector2<f32>) -> &mut Self
Sets the new minimum size of the widget.
sourcepub fn set_min_width(&mut self, value: f32) -> &mut Self
pub fn set_min_width(&mut self, value: f32) -> &mut Self
Sets the new minimum width of the widget.
sourcepub fn set_min_height(&mut self, value: f32) -> &mut Self
pub fn set_min_height(&mut self, value: f32) -> &mut Self
Sets the new minimum height of the widget.
sourcepub fn min_height(&self) -> f32
pub fn min_height(&self) -> f32
Returns the minimum height of the widget.
sourcepub fn is_drag_allowed(&self) -> bool
pub fn is_drag_allowed(&self) -> bool
Return true if the dragging of the widget is allowed, false - otherwise.
sourcepub fn is_drop_allowed(&self) -> bool
pub fn is_drop_allowed(&self) -> bool
Return true if the dropping of other widgets is allowed on this widget, false - otherwise.
sourcepub fn screen_to_local(&self, point: Vector2<f32>) -> Vector2<f32>
pub fn screen_to_local(&self, point: Vector2<f32>) -> Vector2<f32>
Maps the given point from screen to local widget’s coordinates.
sourcepub fn invalidate_layout(&self)
pub fn invalidate_layout(&self)
Invalidates layout of the widget. WARNING: Do not use this method, unless you understand what you’re doing, it will cause new layout pass for this widget which could be quite heavy and doing so on every frame for multiple widgets will cause severe performance issues.
sourcepub fn invalidate_measure(&self)
pub fn invalidate_measure(&self)
Invalidates measurement results of the widget. WARNING: Do not use this method, unless you understand what you’re doing, it will cause new measurement pass for this widget which could be quite heavy and doing so on every frame for multiple widgets will cause severe performance issues.
sourcepub fn invalidate_arrange(&self)
pub fn invalidate_arrange(&self)
Invalidates arrangement results of the widget. WARNING: Do not use this method, unless you understand what you’re doing, it will cause new arrangement pass for this widget which could be quite heavy and doing so on every frame for multiple widgets will cause severe performance issues.
sourcepub fn is_hit_test_visible(&self) -> bool
pub fn is_hit_test_visible(&self) -> bool
Returns true if the widget is able to participate in hit testing, false - otherwise.
sourcepub fn set_max_size(&mut self, value: Vector2<f32>) -> &mut Self
pub fn set_max_size(&mut self, value: Vector2<f32>) -> &mut Self
Sets the new maximum size of the widget.
sourcepub fn max_height(&self) -> f32
pub fn max_height(&self) -> f32
Return maximum height of the widget.
sourcepub fn set_z_index(&mut self, z_index: usize) -> &mut Self
pub fn set_z_index(&mut self, z_index: usize) -> &mut Self
Sets new Z index for the widget. Z index defines the sorting (stable) index which will be used to “arrange” widgets in the correct order.
sourcepub fn set_background(&mut self, brush: Brush) -> &mut Self
pub fn set_background(&mut self, brush: Brush) -> &mut Self
Sets the new background of the widget.
sourcepub fn background(&self) -> Brush
pub fn background(&self) -> Brush
Returns current background of the widget.
sourcepub fn set_foreground(&mut self, brush: Brush) -> &mut Self
pub fn set_foreground(&mut self, brush: Brush) -> &mut Self
Sets new foreground of the widget.
sourcepub fn foreground(&self) -> Brush
pub fn foreground(&self) -> Brush
Returns current foreground of the widget.
sourcepub fn is_draw_on_top(&self) -> bool
pub fn is_draw_on_top(&self) -> bool
Return true if the widget is set to be drawn on top of every other, normally drawn, widgets, false - otherwise.
sourcepub fn set_height(&mut self, height: f32) -> &mut Self
pub fn set_height(&mut self, height: f32) -> &mut Self
Sets new height of the widget.
sourcepub fn set_desired_local_position(&mut self, pos: Vector2<f32>) -> &mut Self
pub fn set_desired_local_position(&mut self, pos: Vector2<f32>) -> &mut Self
Sets the desired local position of the widget.
sourcepub fn screen_position(&self) -> Vector2<f32>
pub fn screen_position(&self) -> Vector2<f32>
Returns current screen-space position of the widget.
sourcepub fn children(&self) -> &[Handle<UiNode>]
pub fn children(&self) -> &[Handle<UiNode>]
Returns a reference to the slice with the children widgets of this widget.
sourcepub fn set_column(&mut self, column: usize) -> &mut Self
pub fn set_column(&mut self, column: usize) -> &mut Self
Sets new column of the widget. Columns are used only by crate::grid::Grid widget.
sourcepub fn column(&self) -> usize
pub fn column(&self) -> usize
Returns current column of the widget. Columns are used only by crate::grid::Grid widget.
sourcepub fn set_row(&mut self, row: usize) -> &mut Self
pub fn set_row(&mut self, row: usize) -> &mut Self
Sets new row of the widget. Rows are used only by crate::grid::Grid widget.
sourcepub fn row(&self) -> usize
pub fn row(&self) -> usize
Returns current row of the widget. Rows are used only by crate::grid::Grid widget.
sourcepub fn desired_size(&self) -> Vector2<f32>
pub fn desired_size(&self) -> Vector2<f32>
Returns the desired size of the widget.
sourcepub fn desired_local_position(&self) -> Vector2<f32>
pub fn desired_local_position(&self) -> Vector2<f32>
Returns current desired local position of the widget.
sourcepub fn screen_bounds(&self) -> Rect<f32>
pub fn screen_bounds(&self) -> Rect<f32>
Returns current screen-space bounds of the widget.
sourcepub fn bounding_rect(&self) -> Rect<f32>
pub fn bounding_rect(&self) -> Rect<f32>
Returns local-space bounding rect of the widget.
sourcepub fn visual_transform(&self) -> &Matrix3<f32>
pub fn visual_transform(&self) -> &Matrix3<f32>
Returns current visual transform of the widget.
sourcepub fn render_transform(&self) -> &Matrix3<f32>
pub fn render_transform(&self) -> &Matrix3<f32>
Returns current render transform of the widget.
sourcepub fn layout_transform(&self) -> &Matrix3<f32>
pub fn layout_transform(&self) -> &Matrix3<f32>
Returns current layout transform of the widget.
sourcepub fn has_descendant(
&self,
node_handle: Handle<UiNode>,
ui: &UserInterface
) -> bool
pub fn has_descendant( &self, node_handle: Handle<UiNode>, ui: &UserInterface ) -> bool
Returns true, if the widget has a descendant widget with the specified handle, false - otherwise.
sourcepub fn find_by_criteria_up<Func: Fn(&UiNode) -> bool>(
&self,
ui: &UserInterface,
func: Func
) -> Handle<UiNode>
pub fn find_by_criteria_up<Func: Fn(&UiNode) -> bool>( &self, ui: &UserInterface, func: Func ) -> Handle<UiNode>
Searches a node up on tree starting from the given root that matches a criteria defined by the given func.
sourcepub fn handle_routed_message(
&mut self,
_ui: &mut UserInterface,
msg: &mut UiMessage
)
pub fn handle_routed_message( &mut self, _ui: &mut UserInterface, msg: &mut UiMessage )
Handles incoming WidgetMessages. This method must be called in crate::control::Control::handle_routed_message
of any derived widgets!
sourcepub fn set_vertical_alignment(
&mut self,
vertical_alignment: VerticalAlignment
) -> &mut Self
pub fn set_vertical_alignment( &mut self, vertical_alignment: VerticalAlignment ) -> &mut Self
Sets new vertical alignment of the widget.
sourcepub fn vertical_alignment(&self) -> VerticalAlignment
pub fn vertical_alignment(&self) -> VerticalAlignment
Returns current vertical alignment of the widget.
sourcepub fn set_horizontal_alignment(
&mut self,
horizontal_alignment: HorizontalAlignment
) -> &mut Self
pub fn set_horizontal_alignment( &mut self, horizontal_alignment: HorizontalAlignment ) -> &mut Self
Sets new horizontal alignment of the widget.
sourcepub fn horizontal_alignment(&self) -> HorizontalAlignment
pub fn horizontal_alignment(&self) -> HorizontalAlignment
Returns current horizontal alignment of the widget.
sourcepub fn set_margin(&mut self, margin: Thickness) -> &mut Self
pub fn set_margin(&mut self, margin: Thickness) -> &mut Self
Sets new margin of the widget.
sourcepub fn measure_override(
&self,
ui: &UserInterface,
available_size: Vector2<f32>
) -> Vector2<f32>
pub fn measure_override( &self, ui: &UserInterface, available_size: Vector2<f32> ) -> Vector2<f32>
Performs standard measurement of children nodes. It provides available size as a constraint and returns the maximum desired size across all children. As a result, this widget will have this size as its desired size to fit all the children nodes.
sourcepub fn arrange_override(
&self,
ui: &UserInterface,
final_size: Vector2<f32>
) -> Vector2<f32>
pub fn arrange_override( &self, ui: &UserInterface, final_size: Vector2<f32> ) -> Vector2<f32>
Performs standard arrangement of the children nodes of the widget. It uses input final size to make a final bounding rectangle to arrange children. As a result, all the children nodes will be located at the top-left corner of this widget and stretched to fit its bounds.
sourcepub fn is_arrange_valid(&self) -> bool
pub fn is_arrange_valid(&self) -> bool
Returns true if the current results of arrangement of the widget are valid, false - otherwise.
sourcepub fn is_measure_valid(&self) -> bool
pub fn is_measure_valid(&self) -> bool
Returns true if the current results of measurement of the widget are valid, false - otherwise.
sourcepub fn actual_local_position(&self) -> Vector2<f32>
pub fn actual_local_position(&self) -> Vector2<f32>
Returns current actual local position of the widget. It is valid only after layout pass!
sourcepub fn center(&self) -> Vector2<f32>
pub fn center(&self) -> Vector2<f32>
Returns center point of the widget. It is valid only after layout pass!
sourcepub fn is_globally_visible(&self) -> bool
pub fn is_globally_visible(&self) -> bool
Returns true of the widget is globally visible, which means that all its parents are visible as well
as this widget. It is valid only after the first update of the layout, otherwise if will be always false.
sourcepub fn set_visibility(&mut self, visibility: bool) -> &mut Self
pub fn set_visibility(&mut self, visibility: bool) -> &mut Self
Sets new visibility of the widget.
sourcepub fn request_update_visibility(&self)
pub fn request_update_visibility(&self)
Requests (via event queue, so the request is deferred) the update of the visibility of the widget.
sourcepub fn visibility(&self) -> bool
pub fn visibility(&self) -> bool
Returns current visibility of the widget.
sourcepub fn set_enabled(&mut self, enabled: bool) -> &mut Self
pub fn set_enabled(&mut self, enabled: bool) -> &mut Self
Enables or disables the widget. Disabled widgets does not interact with user and usually greyed out.
sourcepub fn set_cursor(&mut self, cursor: Option<CursorIcon>)
pub fn set_cursor(&mut self, cursor: Option<CursorIcon>)
Sets new cursor of the widget.
sourcepub fn cursor(&self) -> Option<CursorIcon>
pub fn cursor(&self) -> Option<CursorIcon>
Returns current cursor of the widget.
sourcepub fn user_data_ref<T: 'static>(&self) -> Option<&T>
pub fn user_data_ref<T: 'static>(&self) -> Option<&T>
Tries to fetch user-defined data of the specified type T.
sourcepub fn clip_bounds(&self) -> Rect<f32>
pub fn clip_bounds(&self) -> Rect<f32>
Returns current clipping bounds of the widget. It is valid only after at least one layout pass.
sourcepub fn set_opacity(&mut self, opacity: Option<f32>) -> &mut Self
pub fn set_opacity(&mut self, opacity: Option<f32>) -> &mut Self
Set new opacity of the widget. Opacity should be in [0.0..1.0] range.
sourcepub fn tooltip(&self) -> Option<RcUiNodeHandle>
pub fn tooltip(&self) -> Option<RcUiNodeHandle>
Returns current tooltip handle of the widget.
sourcepub fn set_tooltip(&mut self, tooltip: Option<RcUiNodeHandle>) -> &mut Self
pub fn set_tooltip(&mut self, tooltip: Option<RcUiNodeHandle>) -> &mut Self
Sets new tooltip handle of the widget (if any).
sourcepub fn tooltip_time(&self) -> f32
pub fn tooltip_time(&self) -> f32
Returns maximum available time to show the tooltip after the cursor was moved away from the widget.
sourcepub fn set_tooltip_time(&mut self, tooltip_time: f32) -> &mut Self
pub fn set_tooltip_time(&mut self, tooltip_time: f32) -> &mut Self
Set the maximum available time to show the tooltip after the cursor was moved away from the widget.
Returns current context menu of the widget.
The context menu receives PopupMessages for being displayed, and so should support those.