pub enum ScrollViewerMessage {
Content(Handle<UiNode>),
BringIntoView(Handle<UiNode>),
VScrollSpeed(f32),
HScrollSpeed(f32),
}Expand description
A set of messages that could be used to alternate the state of a ScrollViewer widget.
Variants
Content(Handle<UiNode>)
Sets the new content of the scroll viewer.
BringIntoView(Handle<UiNode>)
Adjusts vertical and horizontal scroll values so given node will be in “view box” of the scroll viewer.
VScrollSpeed(f32)
Sets the new vertical scrolling speed.
HScrollSpeed(f32)
Sets the new horizontal scrolling speed.
Implementations
sourceimpl ScrollViewerMessage
impl ScrollViewerMessage
sourcepub fn content(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Handle<UiNode>
) -> UiMessage
pub fn content( destination: Handle<UiNode>, direction: MessageDirection, value: Handle<UiNode> ) -> UiMessage
Creates ScrollViewerMessage::Content message.
sourcepub fn bring_into_view(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Handle<UiNode>
) -> UiMessage
pub fn bring_into_view( destination: Handle<UiNode>, direction: MessageDirection, value: Handle<UiNode> ) -> UiMessage
Creates ScrollViewerMessage::BringIntoView message.
sourcepub fn v_scroll_speed(
destination: Handle<UiNode>,
direction: MessageDirection,
value: f32
) -> UiMessage
pub fn v_scroll_speed( destination: Handle<UiNode>, direction: MessageDirection, value: f32 ) -> UiMessage
Creates ScrollViewerMessage::VScrollSpeed message.
sourcepub fn h_scroll_speed(
destination: Handle<UiNode>,
direction: MessageDirection,
value: f32
) -> UiMessage
pub fn h_scroll_speed( destination: Handle<UiNode>, direction: MessageDirection, value: f32 ) -> UiMessage
Creates ScrollViewerMessage::HScrollSpeed message.