Module fyrox_ui::stack_panel

source ·
Stack panel orders its children widgets linearly; either top-to-bottom or left-to-right. See StackPanel docs for more info and usage examples.

Structs

  • Stack Panels are one of several methods to position multiple widgets in relation to each other. A Stack Panel Widget orders its children widgets linearly, aka in a stack of widgets, based on the order the widgets were added as children. So the first widget added will be at the top or left most position, while each additional widget will descend from top to bottom or continue from left most to right most. The below example code places 3 text widgets into a vertical stack:
  • Stack panel builders creates StackPanel widgets and registers them in the user interface.

Enums