pub struct RestrictionEntry {
    pub handle: Handle<UiNode>,
    pub stop: bool,
}

Fields

handle: Handle<UiNode>

Handle to UI node to which picking must be restricted to.

stop: bool

A flag that tells UI to stop iterating over picking stack. There are two use cases: chain of menus (popups) and set of modal windows. In case of menus you need to restrict picking to an entire chain, but leave possibility to select any menu in the chain. In case of multiple modal windows you need to restrict picking individually per window, not allowing to pick anything behind modal window, but still save restrictions in the entire chain of modal windows so if topmost closes, restriction will be on previous one and so on.