Struct fyrox_ui::Thickness

source ·
pub struct Thickness {
    pub left: f32,
    pub top: f32,
    pub right: f32,
    pub bottom: f32,
}
Describes the thickness of a frame around a rectangle (for all four sides). It is primarily used to define margins and to define stroke thickness for various widgets.

Fields

left: f32

Thickness of the left side of a rectangle.

top: f32

Thickness of the top side of a rectangle.

right: f32

Thickness of the right side of a rectangle.

bottom: f32

Thickness of the bottom side of a rectangle.

Implementations

source

impl Thickness

source

pub fn zero() -> Self

Degenerate thickness that has no effect.

source

pub fn uniform(v: f32) -> Self

Uniform thickness for all four sides of a rectangle.

source

pub fn bottom(v: f32) -> Self

Thickness for the bottom side of a rectangle.

source

pub fn top(v: f32) -> Self

Thickness for the top side of a rectangle.

source

pub fn left(v: f32) -> Self

Thickness for the left side of a rectangle.

source

pub fn right(v: f32) -> Self

Thickness for the rigth side of a rectangle.

source

pub fn top_right(v: f32) -> Self

Thickness for the top and right sides of a rectangle.

source

pub fn top_left(v: f32) -> Self

Thickness for the top and left sides of a rectangle.

source

pub fn bottom_right(v: f32) -> Self

Thickness for the bottom and right sides of a rectangle.

source

pub fn bottom_left(v: f32) -> Self

Thickness for the bottom and left sides of a rectangle.

source

pub fn top_bottom(v: f32) -> Self

Thickness for the top and bottom sides of a rectangle.

source

pub fn left_right(v: f32) -> Self

Thickness for the left and right sides of a rectangle.

source

pub fn offset(&self) -> Vector2<f32>

Returns an offset defined by this thickness. It is just a vector (left, top).

source

pub fn axes_margin(&self) -> Vector2<f32>

Returns a margin for each axis (horizontal and vertical).