Struct fyrox_ui::tab_control::Tab
source · pub struct Tab {
pub header_button: Handle<UiNode>,
pub content: Handle<UiNode>,
pub close_button: Handle<UiNode>,
pub header_container: Handle<UiNode>,
pub user_data: Option<TabUserData>,
pub decorator: Handle<UiNode>,
pub header_content: Handle<UiNode>,
}Expand description
Tab of the TabControl widget. It stores important tab data, that is widely used at runtime.
Fields
A handle of the header button, that is used to switch tabs.
content: Handle<UiNode>Tab’s content.
A handle of a button, that is used to close the tab.
header_container: Handle<UiNode>A handle to a container widget, that holds the header.
user_data: Option<TabUserData>User-defined data.
decorator: Handle<UiNode>A handle of a node that is used to highlight tab’s state.
header_content: Handle<UiNode>Content of the tab-switching (header) button.