Struct fyrox_ui::tab_control::TabControlBuilder
source · pub struct TabControlBuilder { /* private fields */ }Expand description
Tab control builder is used to create TabControl widget instances and add them to the user interface.
Implementations
sourceimpl TabControlBuilder
impl TabControlBuilder
sourcepub fn new(widget_builder: WidgetBuilder) -> Self
pub fn new(widget_builder: WidgetBuilder) -> Self
Creates new tab control builder.
sourcepub fn with_tab(self, tab: TabDefinition) -> Self
pub fn with_tab(self, tab: TabDefinition) -> Self
Adds a new tab to the builder.
sourcepub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>
Finishes TabControl building and adds it to the user interface and returns its handle.