Struct fyrox_ui::tab_control::TabDefinition
source · pub struct TabDefinition {
pub header: Handle<UiNode>,
pub content: Handle<UiNode>,
pub can_be_closed: bool,
pub user_data: Option<TabUserData>,
}Expand description
Tab definition is used to describe content of each tab for the TabControlBuilder builder.
Fields
header: Handle<UiNode>Content of the tab-switching (header) button.
content: Handle<UiNode>Content of the tab.
can_be_closed: boolA flag, that defines whether the tab can be closed or not.
user_data: Option<TabUserData>User-defined data.