TextBuilder

Struct TextBuilder 

pub struct TextBuilder { /* private fields */ }
TextBuilder is used to create instances of Text widget and register them in the user interface.

Implementations

Source

impl TextBuilder

pub fn new(widget_builder: WidgetBuilder) -> Self

Creates new TextBuilder instance using the provided base widget builder.

pub fn with_bbcode<P: Into<String>>(self, text: P) -> Self

Sets the desired text of the widget, with BBcode tags that will automatically generate the formatting runs and replace any other runs set through this builder.

pub fn with_text<P: Into<String>>(self, text: P) -> Self

Sets the desired text of the widget.

pub fn with_font(self, font: FontResource) -> Self

Sets the desired font of the widget.

pub fn with_opt_font(self, font: Option<FontResource>) -> Self

Sets the desired font of the widget using font wrapped in Option.

pub fn with_vertical_text_alignment(self, valign: VerticalAlignment) -> Self

Sets the desired vertical alignment of the widget.

pub fn with_font_size(self, font_size: StyledProperty<f32>) -> Self

Sets the desired height of the text.

pub fn with_horizontal_text_alignment(self, halign: HorizontalAlignment) -> Self

Sets the desired horizontal alignment of the widget.

pub fn with_wrap(self, wrap: WrapMode) -> Self

Sets the desired word wrapping mode of the widget.

pub fn with_shadow(self, shadow: bool) -> Self

Whether the shadow enabled or not.

pub fn with_shadow_brush(self, brush: Brush) -> Self

Sets desired shadow brush. It will be used to render the shadow.

pub fn with_shadow_dilation(self, thickness: f32) -> Self

Sets desired shadow dilation in units. Keep in mind that the dilation is absolute, not percentage-based.

pub fn with_shadow_offset(self, offset: Vector2<f32>) -> Self

Sets desired shadow offset in units.

pub fn with_run(self, run: Run) -> Self

Adds the given run to the text to set the style for a portion of the text. Later runs potentially overriding earlier runs if the ranges of the runs overlap and the later run sets a property that conflicts with an earlier run.

pub fn with_runs<I: IntoIterator<Item = Run>>(self, runs: I) -> Self

Adds multiple runs to the text to set the style of portions of the text. Later runs potentially overriding earlier runs if the ranges of the runs overlap and the later run sets a property that conflicts with an earlier run.

pub fn with_trim_text(self, trim: bool) -> Self

A flag, that defines whether the formatted text should add ellipsis (…) to lines that goes outside provided bounds.

pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<Text>

Finishes text widget creation and registers it in the user interface, returning its handle to you.