Enum fyrox_ui::text_box::TextBoxMessage
source · pub enum TextBoxMessage {
SelectionBrush(Brush),
CaretBrush(Brush),
TextCommitMode(TextCommitMode),
Multiline(bool),
Editable(bool),
}Expand description
A message that could be used to alternate text box widget’s state or receive changes from it.
Important notes
Text box widget also supports TextMessage and WidgetMessage.
Variants
SelectionBrush(Brush)
Used to change selection brush of a text box. Use TextBoxMessage::selection_brush` to create the message.
CaretBrush(Brush)
Used to change caret brush of a text box. Use TextBoxMessage::caret_brush` to create the message.
TextCommitMode(TextCommitMode)
Used to change text commit mode of a text box. Use TextBoxMessage::text_commit_mode` to create the message.
Multiline(bool)
Used to enable or disable multiline mode of a text box. Use TextBoxMessage::multiline` to create the message.
Editable(bool)
Used to enable or disable an ability to edit text box content. Use TextBoxMessage::editable` to create the message.
Implementations
sourceimpl TextBoxMessage
impl TextBoxMessage
sourcepub fn selection_brush(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Brush
) -> UiMessage
pub fn selection_brush( destination: Handle<UiNode>, direction: MessageDirection, value: Brush ) -> UiMessage
Creates TextBoxMessage::SelectionBrush.
sourcepub fn caret_brush(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Brush
) -> UiMessage
pub fn caret_brush( destination: Handle<UiNode>, direction: MessageDirection, value: Brush ) -> UiMessage
Creates TextBoxMessage::CaretBrush.
sourcepub fn text_commit_mode(
destination: Handle<UiNode>,
direction: MessageDirection,
value: TextCommitMode
) -> UiMessage
pub fn text_commit_mode( destination: Handle<UiNode>, direction: MessageDirection, value: TextCommitMode ) -> UiMessage
Creates TextBoxMessage::TextCommitMode.
sourcepub fn multiline(
destination: Handle<UiNode>,
direction: MessageDirection,
value: bool
) -> UiMessage
pub fn multiline( destination: Handle<UiNode>, direction: MessageDirection, value: bool ) -> UiMessage
Creates TextBoxMessage::Multiline.
sourcepub fn editable(
destination: Handle<UiNode>,
direction: MessageDirection,
value: bool
) -> UiMessage
pub fn editable( destination: Handle<UiNode>, direction: MessageDirection, value: bool ) -> UiMessage
Creates TextBoxMessage::Editable.