#[repr(u32)]
pub enum TextCommitMode { Immediate, LostFocus, LostFocusPlusEnter, }
Defines the way, how the text box widget will commit the text that was typed in

Variants



Immediate

Text box will immediately send TextMessage::Text message after any change (after any pressed button).



LostFocus

Text box will send Text message only when it loses focus (when a user “clicks” outside of it or with any other event that forces the text box to lose focus).



LostFocusPlusEnter

Text box will send Text message when it loses focus or if Enter key was pressed. This is default behavior.

Notes

In case of multiline text box hitting Enter key won’t commit the text!