Struct fyrox_ui::text_box::SelectionRange
source · pub struct SelectionRange {
pub begin: Position,
pub end: Position,
}Expand description
Defines a set of two positions in the text, that forms a specific range.
Fields
begin: PositionPosition of the beginning.
end: PositionPosition of the end.
Implementations
sourceimpl SelectionRange
impl SelectionRange
sourcepub fn normalized(&self) -> SelectionRange
pub fn normalized(&self) -> SelectionRange
Creates a new range, that have its begin always before end. It could be useful in case if user selects a range right-to-left.