Struct fyrox_ui::text_box::TextBox

source ·
pub struct TextBox {
Show 17 fields pub widget: Widget, pub caret_position: Position, pub caret_visible: bool, pub blink_timer: f32, pub blink_interval: f32, pub formatted_text: RefCell<FormattedText>, pub selection_range: Option<SelectionRange>, pub selecting: bool, pub has_focus: bool, pub caret_brush: Brush, pub selection_brush: Brush, pub filter: Option<Rc<RefCell<FilterCallback>>>, pub commit_mode: TextCommitMode, pub multiline: bool, pub editable: bool, pub view_position: Vector2<f32>, pub skip_chars: Vec<u32>,
}

Fields

widget: Widgetcaret_position: Positioncaret_visible: boolblink_timer: f32blink_interval: f32formatted_text: RefCell<FormattedText>selection_range: Option<SelectionRange>selecting: boolhas_focus: boolcaret_brush: Brushselection_brush: Brushfilter: Option<Rc<RefCell<FilterCallback>>>commit_mode: TextCommitModemultiline: booleditable: boolview_position: Vector2<f32>skip_chars: Vec<u32>

Implementations

Maps input Position to a linear position in character array. Output index can be equal to length of text, this means that position is at the end of the text. You should check the index before trying to use it to fetch data from inner array of characters.

Maps input Position to a linear position in character array. Output index will always be valid for fetching, if the method returned Some(index). The index however cannot be used for text insertion, because it cannot point to a “place after last char”.

Methods from Deref<Target = Widget>

Returns size of the widget without any layout or rendering transform applied.

Searches a node up on tree starting from given root that matches a criteria defined by a given func.

The context menu receives PopupMessages for being displayed, and so should support those.