pub enum Primitive {
    Triangle {
        points: [Vector2<f32>; 3],
    },
    Line {
        begin: Vector2<f32>,
        end: Vector2<f32>,
        thickness: f32,
    },
    Circle {
        center: Vector2<f32>,
        radius: f32,
        segments: usize,
    },
    Rectangle {
        rect: Rect<f32>,
        thickness: f32,
    },
    RectangleFilled {
        rect: Rect<f32>,
    },
}
Primitive is a simplest shape, that consists of one or multiple lines of the same thickness.

Variants



Triangle

Fields

points: [Vector2<f32>; 3]

Points of the triangle in local coordinates.

Solid triangle primitive.



Line

Fields

begin: Vector2<f32>

Beginning of the line in local coordinates.

end: Vector2<f32>

End of the line in local coordinates.

thickness: f32

Thickness of the line in absolute units.

A line of fixed thickness between two points.



Circle

Fields

center: Vector2<f32>

Center of the circle in local coordinates.

radius: f32

Radius of the circle in absolute units.

segments: usize

Amount of segments that is used to approximate the circle using triangles. The higher the value, the smoother the circle and vice versa.

Solid circle primitive.



Rectangle

Fields

rect: Rect<f32>

Rectangle bounds in local coordinates.

thickness: f32

Thickness of the lines on the rectangle in absolute units.

Wireframe rectangle primitive.



RectangleFilled

Fields

rect: Rect<f32>

Rectangle bounds in local coordinates.

Solid rectangle primitive.

Implementations

source

impl Primitive

source

pub fn bounds(&self) -> (Vector2<f32>, Vector2<f32>)

Returns current bounds of the primitive as min, max tuple.