pub enum WindowMessage {
Show 13 variants Open { center: bool, }, OpenModal { center: bool, }, Close, Minimize(bool), Maximize, CanMinimize(bool), CanClose(bool), CanResize(bool), MoveStart, Move(Vector2<f32>), MoveEnd, Title(WindowTitle), SafeBorderSize(Option<Vector2<f32>>),
}
A set of possible messages that can be used to modify the state of a window or listen to changes in the window.

Variants



Open

Fields

center: bool

A flag that defines whether the window should be centered or not.

Opens a window.



OpenModal

Fields

center: bool

A flag that defines whether the window should be centered or not.

Opens window in modal mode. Modal mode does not blocks current thread, instead it just restricts mouse and keyboard events only to window so other content is not clickable/type-able. Closing a window removes that restriction.



Close

Closes a window.



Minimize(bool)

Minimizes a window - it differs from classic minimization in window managers, instead of putting window in system tray, it just collapses internal content panel.



Maximize

Forces the window to take the inner size of main application window.



CanMinimize(bool)

Whether or not window can be minimized by _ mark. false hides _ mark.



CanClose(bool)

Whether or not window can be closed by X mark. false hides X mark.



CanResize(bool)

Whether or not window can be resized by resize grips.



MoveStart

Indicates that move has been started. You should never send this message by hand.



Move(Vector2<f32>)

Moves window to a new position in local coordinates.



MoveEnd

Indicated that move has ended. You should never send this message by hand.



Title(WindowTitle)

Sets new window title.



SafeBorderSize(Option<Vector2<f32>>)

Safe border size defines “part” of a window that should always be on screen when dragged. It is used to prevent moving window outside of main application window bounds, to still be able to drag it.

Implementations

source

impl WindowMessage

source

pub fn open( destination: Handle<UiNode>, direction: MessageDirection, center: bool ) -> UiMessage

Creates WindowMessage::Open message.

source

pub fn open_modal( destination: Handle<UiNode>, direction: MessageDirection, center: bool ) -> UiMessage

Creates WindowMessage::OpenModal message.

source

pub fn close( destination: Handle<UiNode>, direction: MessageDirection ) -> UiMessage

Creates WindowMessage::Close message.

source

pub fn minimize( destination: Handle<UiNode>, direction: MessageDirection, value: bool ) -> UiMessage

Creates WindowMessage::Minimize message.

source

pub fn maximize( destination: Handle<UiNode>, direction: MessageDirection ) -> UiMessage

Creates WindowMessage::Maximize message.

source

pub fn can_minimize( destination: Handle<UiNode>, direction: MessageDirection, value: bool ) -> UiMessage

Creates WindowMessage::CanMinimize message.

source

pub fn can_close( destination: Handle<UiNode>, direction: MessageDirection, value: bool ) -> UiMessage

Creates WindowMessage::CanClose message.

source

pub fn can_resize( destination: Handle<UiNode>, direction: MessageDirection, value: bool ) -> UiMessage

Creates WindowMessage::CanResize message.

source

pub fn move_start( destination: Handle<UiNode>, direction: MessageDirection ) -> UiMessage

Creates WindowMessage::MoveStart message.

source

pub fn move_to( destination: Handle<UiNode>, direction: MessageDirection, value: Vector2<f32> ) -> UiMessage

Creates WindowMessage::Move message.

source

pub fn move_end( destination: Handle<UiNode>, direction: MessageDirection ) -> UiMessage

Creates WindowMessage::MoveEnd message.

source

pub fn title( destination: Handle<UiNode>, direction: MessageDirection, value: WindowTitle ) -> UiMessage

Creates WindowMessage::Title message.

source

pub fn safe_border_size( destination: Handle<UiNode>, direction: MessageDirection, value: Option<Vector2<f32>> ) -> UiMessage