Enum fyrox_ui::button::ButtonContent
source · pub enum ButtonContent {
Text {
text: String,
font: Option<SharedFont>,
},
Node(Handle<UiNode>),
}Expand description
Possible button content. In general, button widget can contain any type of widget inside. This enum contains a special shortcuts for most commonly used cases - button with the default font, button with custom font, or button with any widget.
Variants
Text
Fields

font: Option<SharedFont>Optional font of the button. If None, the default font will be used.
A shortcut to create a crate::text::Text widget as the button content. It is the same as creating Text widget yourself, but much shorter.
Node(Handle<UiNode>)
Arbitrary widget handle. It could be any widget handle, for example a handle of crate::image::Image
widget.
Implementations
sourceimpl ButtonContent
impl ButtonContent
sourcepub fn text<S: AsRef<str>>(s: S) -> Self
pub fn text<S: AsRef<str>>(s: S) -> Self
Creates ButtonContent::Text with default font.
sourcepub fn text_with_font<S: AsRef<str>>(s: S, font: SharedFont) -> Self
pub fn text_with_font<S: AsRef<str>>(s: S, font: SharedFont) -> Self
Creates ButtonContent::Text with custom font.
sourcepub fn node(node: Handle<UiNode>) -> Self
pub fn node(node: Handle<UiNode>) -> Self
Creates ButtonContent::Node.