Enum fyrox_ui::HorizontalAlignment
source · pub enum HorizontalAlignment {
Stretch,
Left,
Center,
Right,
}Expand description
Horizontal alignment defines relative location and size of the widget to its parent widget along horizontal (X) axis.
Variants
Stretch
Tells the widget to take all available space along horizontal axis and stay at left side of the parent widget. This is default horizontal alignment for all widgets.
Left
Tells the widget to stay at the left side of the parent widget and take as less space as possible (shrink-to-fit).
Center
Tells the widget to stay at the center of the parent widget and take as less space as possible (shrink-to-fit).
Right
Tells the widget to stay at the right side of the parent widget and take as less space as possible (shrink-to-fit).