Enum fyrox_ui::list_view::ListViewMessage
source · pub enum ListViewMessage {
SelectionChanged(Option<usize>),
Items(Vec<Handle<UiNode>>),
AddItem(Handle<UiNode>),
RemoveItem(Handle<UiNode>),
BringItemIntoView(Handle<UiNode>),
}Expand description
A set of messages that can be used to modify/fetch the state of a ListView widget at runtime.
Variants
SelectionChanged(Option<usize>)
Items(Vec<Handle<UiNode>>)
A message, that is used to set new items of a list view.
AddItem(Handle<UiNode>)
A message, that is used to add an item to a list view.
RemoveItem(Handle<UiNode>)
A message, that is used to remove an item from a list view.
BringItemIntoView(Handle<UiNode>)
A message, that is used to bring an item into view.
Implementations
sourceimpl ListViewMessage
impl ListViewMessage
sourcepub fn selection(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Option<usize>
) -> UiMessage
pub fn selection( destination: Handle<UiNode>, direction: MessageDirection, value: Option<usize> ) -> UiMessage
Creates ListViewMessage::SelectionChanged message.
sourcepub fn items(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Vec<Handle<UiNode>>
) -> UiMessage
pub fn items( destination: Handle<UiNode>, direction: MessageDirection, value: Vec<Handle<UiNode>> ) -> UiMessage
Creates ListViewMessage::Items message.
sourcepub fn add_item(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Handle<UiNode>
) -> UiMessage
pub fn add_item( destination: Handle<UiNode>, direction: MessageDirection, value: Handle<UiNode> ) -> UiMessage
Creates ListViewMessage::AddItem message.
sourcepub fn remove_item(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Handle<UiNode>
) -> UiMessage
pub fn remove_item( destination: Handle<UiNode>, direction: MessageDirection, value: Handle<UiNode> ) -> UiMessage
Creates ListViewMessage::RemoveItem message.
sourcepub fn bring_item_into_view(
destination: Handle<UiNode>,
direction: MessageDirection,
value: Handle<UiNode>
) -> UiMessage
pub fn bring_item_into_view( destination: Handle<UiNode>, direction: MessageDirection, value: Handle<UiNode> ) -> UiMessage
Creates ListViewMessage::BringItemIntoView message.