pub trait MessageData: 'static + Debug + Any {
    // Required methods
    fn as_any(&self) -> &dyn Any;
    fn compare(&self, other: &dyn MessageData) -> bool;
}
A trait, that is used by every messages used in the user interface. It contains utility methods, that are used for downcasting and equality comparison.

Required Methods

source

fn as_any(&self) -> &dyn Any

Casts self as Any reference.

source

fn compare(&self, other: &dyn MessageData) -> bool

Compares this message data with some other.

Implementors

source

impl<T> MessageData for Twhere T: 'static + Debug + PartialEq + Any,