Trait fyrox_ui::message::MessageData
source · pub trait MessageData: 'static + Debug + Any {
// Required methods
fn as_any(&self) -> &dyn Any;
fn compare(&self, other: &dyn MessageData) -> bool;
}Expand description
A trait, that is used by every messages used in the user interface. It contains utility methods, that are used for downcasting and equality comparison.
Required Methods
sourcefn compare(&self, other: &dyn MessageData) -> bool
fn compare(&self, other: &dyn MessageData) -> bool
Compares this message data with some other.