A widget that handles numbers of any machine type. See NumericUpDown docs for more info and usage examples.
Structs
- A widget that handles numbers of any machine type. Use this widget if you need to provide input field for a numeric type.
- This builder creates new instances of
NumericUpDownwidget and adds them to the user interface.
Enums
- Used to store drag info when dragging the cursor on the up/down buttons.
- A set of messages that can be used to modify
NumericUpDownwidget state (withMessageDirection::ToWidget, or to fetch changes from it (withMessageDirection::FromWidget).
Traits
- Numeric type is a trait, that has all required traits of a number type. It is used as a useful abstraction over all machine numeric types.