pub struct Thickness {
pub left: f32,
pub top: f32,
pub right: f32,
pub bottom: f32,
}Expand description
Describes the thickness of a frame around a rectangle (for all four sides). It is primarily used to define margins and to define stroke thickness for various widgets.
Fields
left: f32Thickness of the left side of a rectangle.
top: f32Thickness of the top side of a rectangle.
right: f32Thickness of the right side of a rectangle.
bottom: f32Thickness of the bottom side of a rectangle.
Implementations
sourceimpl Thickness
impl Thickness
sourcepub fn bottom_right(v: f32) -> Self
pub fn bottom_right(v: f32) -> Self
Thickness for the bottom and right sides of a rectangle.
sourcepub fn bottom_left(v: f32) -> Self
pub fn bottom_left(v: f32) -> Self
Thickness for the bottom and left sides of a rectangle.
sourcepub fn top_bottom(v: f32) -> Self
pub fn top_bottom(v: f32) -> Self
Thickness for the top and bottom sides of a rectangle.
sourcepub fn left_right(v: f32) -> Self
pub fn left_right(v: f32) -> Self
Thickness for the left and right sides of a rectangle.
sourcepub fn offset(&self) -> Vector2<f32>
pub fn offset(&self) -> Vector2<f32>
Returns an offset defined by this thickness. It is just a vector (left, top).
sourcepub fn axes_margin(&self) -> Vector2<f32>
pub fn axes_margin(&self) -> Vector2<f32>
Returns a margin for each axis (horizontal and vertical).