pub struct WidgetBuilder {
Show 32 fields pub name: String, pub width: f32, pub height: f32, pub desired_position: Vector2<f32>, pub vertical_alignment: VerticalAlignment, pub horizontal_alignment: HorizontalAlignment, pub max_size: Option<Vector2<f32>>, pub min_size: Option<Vector2<f32>>, pub background: Option<Brush>, pub foreground: Option<Brush>, pub row: usize, pub column: usize, pub margin: Thickness, pub children: Vec<Handle<UiNode>>, pub is_hit_test_visible: bool, pub visibility: bool, pub z_index: usize, pub allow_drag: bool, pub allow_drop: bool, pub user_data: Option<Rc<dyn Any>>, pub draw_on_top: bool, pub enabled: bool, pub cursor: Option<CursorIcon>, pub opacity: Option<f32>, pub tooltip: Rc<Handle<UiNode>>, pub tooltip_time: f32, pub context_menu: Handle<UiNode>, pub preview_messages: bool, pub handle_os_events: bool, pub layout_transform: Matrix3<f32>, pub render_transform: Matrix3<f32>, pub clip_to_bounds: bool,
}

Fields

name: Stringwidth: f32height: f32desired_position: Vector2<f32>vertical_alignment: VerticalAlignmenthorizontal_alignment: HorizontalAlignmentmax_size: Option<Vector2<f32>>min_size: Option<Vector2<f32>>background: Option<Brush>foreground: Option<Brush>row: usizecolumn: usizemargin: Thicknesschildren: Vec<Handle<UiNode>>is_hit_test_visible: boolvisibility: boolz_index: usizeallow_drag: boolallow_drop: booluser_data: Option<Rc<dyn Any>>draw_on_top: boolenabled: boolcursor: Option<CursorIcon>opacity: Option<f32>tooltip: Rc<Handle<UiNode>>tooltip_time: f32context_menu: Handle<UiNode>preview_messages: boolhandle_os_events: boollayout_transform: Matrix3<f32>render_transform: Matrix3<f32>clip_to_bounds: bool

Implementations

Sets the desired tooltip for the node.

Important

The widget will share the tooltip, which means that when widget will be deleted, the tooltip will be deleted only if there’s no one use the tooltip anymore.

The context menu receives PopupMessages for being displayed, and so should support those.