pub struct WindowBuilder {
Show 13 fields pub widget_builder: WidgetBuilder, pub content: Handle<UiNode>, pub title: Option<WindowTitle>, pub can_close: bool, pub can_minimize: bool, pub can_maximize: bool, pub open: bool, pub close_button: Option<Handle<UiNode>>, pub minimize_button: Option<Handle<UiNode>>, pub maximize_button: Option<Handle<UiNode>>, pub modal: bool, pub can_resize: bool, pub safe_border_size: Option<Vector2<f32>>,
}
Window builder creates Window instances and adds them to the user interface.

Fields

widget_builder: WidgetBuilder

Base widget builder.

content: Handle<UiNode>

Content of the window.

title: Option<WindowTitle>

Optional title of the window.

can_close: bool

Whether the window can be closed or not.

can_minimize: bool

Whether the window can be minimized or not.

can_maximize: bool

Whether the window can be maximized or not.

open: bool

Whether the window should be created open or not.

close_button: Option<Handle<UiNode>>

Optional custom closing button, if not specified, then a default button will be created.

minimize_button: Option<Handle<UiNode>>

Optional custom minimization button, if not specified, then a default button will be created.

maximize_button: Option<Handle<UiNode>>

Optional custom maximization button, if not specified, then a default button will be created.

modal: bool

Whether the window should be created as modal or not. Warning: Any dependant builders must take this into account!

can_resize: bool

Whether the window should be resizable or not.

safe_border_size: Option<Vector2<f32>>

Optional size of the border around the screen in which the window will be forced to stay.

Implementations

source

impl WindowBuilder

source

pub fn new(widget_builder: WidgetBuilder) -> Self

Creates new window builder.

source

pub fn with_content(self, content: Handle<UiNode>) -> Self

Sets a desired window content.

source

pub fn with_title(self, title: WindowTitle) -> Self

Sets a desired window title.

source

pub fn with_minimize_button(self, button: Handle<UiNode>) -> Self

Sets a desired minimization button.

source

pub fn with_maximize_button(self, button: Handle<UiNode>) -> Self

Sets a desired maximization button.

source

pub fn with_close_button(self, button: Handle<UiNode>) -> Self

Sets a desired closing button.

source

pub fn can_close(self, can_close: bool) -> Self

Sets whether the window can be closed or not.

source

pub fn can_minimize(self, can_minimize: bool) -> Self

Sets whether the window can be minimized or not.

source

pub fn can_maximize(self, can_minimize: bool) -> Self

Sets whether the window can be maximized or not.

source

pub fn open(self, open: bool) -> Self

Sets whether the window should be open or not.

source

pub fn modal(self, modal: bool) -> Self

Sets whether the window should be modal or not.

source

pub fn can_resize(self, can_resize: bool) -> Self

Sets whether the window can be resized or not.

source

pub fn with_safe_border_size(self, size: Option<Vector2<f32>>) -> Self

Sets a desired safe border size.

source

pub fn build_window(self, ctx: &mut BuildContext<'_>) -> Window

Finishes window building and returns its instance.

source

pub fn build(self, ctx: &mut BuildContext<'_>) -> Handle<UiNode>

Finishes window building and returns its handle.